import type { CreateDonor } from '../models/CreateDonor';
import type { ResponseDonor } from '../models/ResponseDonor';
import type { ResponseEmpty } from '../models/ResponseEmpty';
import type { UpdateDonor } from '../models/UpdateDonor';
export declare class DonorService {
    /**
     * Get all
     * Lists all donor. <br> This includes the donor's current donation amount.
     * @result ResponseDonor
     * @throws ApiError
     */
    static donorControllerGetAll(): Promise<Array<ResponseDonor>>;
    /**
     * Post
     * Create a new donor.
     * @param requestBody CreateDonor
     * @result ResponseDonor
     * @throws ApiError
     */
    static donorControllerPost(requestBody?: CreateDonor): Promise<ResponseDonor>;
    /**
     * Get one
     * Lists all information about the donor whose id got provided. <br> This includes the donor's current donation amount.
     * @param id
     * @result ResponseDonor
     * @throws ApiError
     */
    static donorControllerGetOne(id: number): Promise<ResponseDonor>;
    /**
     * Put
     * Update the donor whose id you provided. <br> Please remember that ids can't be changed.
     * @param id
     * @param requestBody UpdateDonor
     * @result ResponseDonor
     * @throws ApiError
     */
    static donorControllerPut(id: number, requestBody?: UpdateDonor): Promise<ResponseDonor>;
    /**
     * Remove
     * Delete the donor whose id you provided. <br> If no donor with this id exists it will just return 204(no content). <br> If the donor still has donations associated this will fail, please provide the query param ?force=true to delete the donor with all associated donations.
     * @param id
     * @param force
     * @result ResponseDonor
     * @result ResponseEmpty
     * @throws ApiError
     */
    static donorControllerRemove(id: number, force?: boolean): Promise<ResponseDonor | ResponseEmpty>;
}
