import type { ImportRunner } from '../models/ImportRunner';
import type { ResponseRunner } from '../models/ResponseRunner';
export declare class ImportService {
    /**
     * Post json
     * Create new runners from json and insert them into the provided group. <br> If teams/classes are provided alongside the runner's name they'll automaticly be created under the provided org and the runners will be inserted into the teams instead.
     * @param group
     * @param requestBody ImportRunner
     * @result ResponseRunner
     * @throws ApiError
     */
    static importControllerPostJson(group?: number, requestBody?: Array<ImportRunner>): Promise<Array<ResponseRunner>>;
    /**
     * Post orgs json
     * Create new runners from json and insert them into the provided org. <br> If teams/classes are provided alongside the runner's name they'll automaticly be created under the provided org and the runners will be inserted into the teams instead.
     * @param id
     * @param requestBody ImportRunner
     * @result ResponseRunner
     * @throws ApiError
     */
    static importControllerPostOrgsJson(id: number, requestBody?: Array<ImportRunner>): Promise<Array<ResponseRunner>>;
    /**
     * Post teams json
     * Create new runners from json and insert them into the provided team
     * @param id
     * @param requestBody ImportRunner
     * @result ResponseRunner
     * @throws ApiError
     */
    static importControllerPostTeamsJson(id: number, requestBody?: Array<ImportRunner>): Promise<Array<ResponseRunner>>;
    /**
     * Post csv
     * Create new runners from csv and insert them into the provided group. <br> If teams/classes are provided alongside the runner's name they'll automaticly be created under the provided org and the runners will be inserted into the teams instead.
     * @param group
     * @result ResponseRunner
     * @throws ApiError
     */
    static importControllerPostCsv(group?: number): Promise<Array<ResponseRunner>>;
    /**
     * Post orgs csv
     * Create new runners from csv and insert them into the provided org. <br> If teams/classes are provided alongside the runner's name they'll automaticly be created under the provided org and the runners will be inserted into the teams instead.
     * @param id
     * @result ResponseRunner
     * @throws ApiError
     */
    static importControllerPostOrgsCsv(id: number): Promise<Array<ResponseRunner>>;
    /**
     * Post teams csv
     * Create new runners from csv and insert them into the provided team
     * @param id
     * @result ResponseRunner
     * @throws ApiError
     */
    static importControllerPostTeamsCsv(id: number): Promise<Array<ResponseRunner>>;
}
