import type { CreateRunnerOrganization } from '../models/CreateRunnerOrganization';
import type { ResponseEmpty } from '../models/ResponseEmpty';
import type { ResponseRunner } from '../models/ResponseRunner';
import type { ResponseRunnerOrganization } from '../models/ResponseRunnerOrganization';
import type { UpdateRunnerOrganization } from '../models/UpdateRunnerOrganization';
export declare class RunnerOrganizationService {
    /**
     * Get all
     * Lists all organizations. <br> This includes their address, contact and teams (if existing/associated).
     * @result ResponseRunnerOrganization
     * @throws ApiError
     */
    static runnerOrganizationControllerGetAll(): Promise<Array<ResponseRunnerOrganization>>;
    /**
     * Post
     * Create a new organsisation.
     * @param requestBody CreateRunnerOrganization
     * @result ResponseRunnerOrganization
     * @throws ApiError
     */
    static runnerOrganizationControllerPost(requestBody?: CreateRunnerOrganization): Promise<ResponseRunnerOrganization>;
    /**
     * Get one
     * Lists all information about the organization whose id got provided.
     * @param id
     * @result ResponseRunnerOrganization
     * @throws ApiError
     */
    static runnerOrganizationControllerGetOne(id: number): Promise<ResponseRunnerOrganization>;
    /**
     * Put
     * Update the organization whose id you provided. <br> Please remember that ids can't be changed.
     * @param id
     * @param requestBody UpdateRunnerOrganization
     * @result ResponseRunnerOrganization
     * @throws ApiError
     */
    static runnerOrganizationControllerPut(id: number, requestBody?: UpdateRunnerOrganization): Promise<ResponseRunnerOrganization>;
    /**
     * Remove
     * Delete the organsisation whose id you provided. <br> If the organization still has runners and/or teams associated this will fail. <br> To delete the organization with all associated runners and teams set the force QueryParam to true (cascading deletion might take a while). <br> This won't delete the associated contact. <br> If no organization with this id exists it will just return 204(no content).
     * @param id
     * @param force
     * @result ResponseRunnerOrganization
     * @result ResponseEmpty
     * @throws ApiError
     */
    static runnerOrganizationControllerRemove(id: number, force?: boolean): Promise<ResponseRunnerOrganization | ResponseEmpty>;
    /**
     * Get runners
     * Lists all runners from this org and it's teams (if you don't provide the ?onlyDirect=true param). <br> This includes the runner's group and distance ran.
     * @param id
     * @param onlyDirect
     * @result ResponseRunner
     * @throws ApiError
     */
    static runnerOrganizationControllerGetRunners(id: number, onlyDirect?: boolean): Promise<Array<ResponseRunner>>;
}
