import type { ResponseStats } from '../models/ResponseStats';
import type { ResponseStatsOrgnisation } from '../models/ResponseStatsOrgnisation';
import type { ResponseStatsRunner } from '../models/ResponseStatsRunner';
import type { ResponseStatsTeam } from '../models/ResponseStatsTeam';
export declare class StatsService {
    /**
     * Get
     * A very basic stats endpoint providing basic counters for a dashboard or simmilar
     * @result ResponseStats
     * @throws ApiError
     */
    static statsControllerGet(): Promise<ResponseStats>;
    /**
     * Get top runners by distance
     * Returns the top ten runners by distance.
     * @result ResponseStatsRunner
     * @throws ApiError
     */
    static statsControllerGetTopRunnersByDistance(): Promise<Array<ResponseStatsRunner>>;
    /**
     * Get top runners by donations
     * Returns the top ten runners by donations.
     * @result ResponseStatsRunner
     * @throws ApiError
     */
    static statsControllerGetTopRunnersByDonations(): Promise<Array<ResponseStatsRunner>>;
    /**
     * Get top runners by laptime
     * Returns the top ten runners by fastest laptime on your selected track (track by id).
     * @param track
     * @result ResponseStatsRunner
     * @throws ApiError
     */
    static statsControllerGetTopRunnersByLaptime(track?: number): Promise<Array<ResponseStatsRunner>>;
    /**
     * Get top runners by track time
     * Returns the top ten fastest track times (with their runner and the runner's group).
     * @result ResponseStatsRunner
     * @throws ApiError
     */
    static statsControllerGetTopRunnersByTrackTime(): Promise<Array<ResponseStatsRunner>>;
    /**
     * Get top teams by distance
     * Returns the top ten teams by distance.
     * @result ResponseStatsTeam
     * @throws ApiError
     */
    static statsControllerGetTopTeamsByDistance(): Promise<Array<ResponseStatsTeam>>;
    /**
     * Get top teams by donations
     * Returns the top ten teams by donations.
     * @result ResponseStatsTeam
     * @throws ApiError
     */
    static statsControllerGetTopTeamsByDonations(): Promise<Array<ResponseStatsTeam>>;
    /**
     * Get top orgs by distance
     * Returns the top ten organizations by distance.
     * @result ResponseStatsOrgnisation
     * @throws ApiError
     */
    static statsControllerGetTopOrgsByDistance(): Promise<Array<ResponseStatsOrgnisation>>;
    /**
     * Get top orgs by donations
     * Returns the top ten organizations by donations.
     * @result ResponseStatsOrgnisation
     * @throws ApiError
     */
    static statsControllerGetTopOrgsByDonations(): Promise<Array<ResponseStatsOrgnisation>>;
}
